@@ -13,12 +13,12 @@ Rules for feature engineering of Circulo de Credito data (FICO scored version):
 
 # Persona specs:
 residence = {
-	0: "na",
-	1: "propietarry",
-	2: "rent",
-	3: "family",
-	4: "mortage",
-	5: "na"
+	"0": "na",
+	"1": "propietarry",
+	"2": "rent",
+	"3": "family",
+	"4": "mortage",
+	"5": "na"
 }
 
 # Civil state specs
