@@ -5,15 +5,25 @@ import json
 import boto3
 import decimal
 
-data_yaml_file = '/data.yml'
+data_yaml_file = '/data'
+extension = '.yml'
 
 
-def get_data_yaml_dict(connection_type):
+def get_data_yaml_dict(connection_type, environment=None):
     try:
         sFile = os.path.abspath(sys.modules['__main__'].__file__)
     except:
         sFile = sys.executable
-    return yaml.load(open(os.path.dirname(sFile) + data_yaml_file), Loader=yaml.FullLoader)[connection_type]
+    file_name = data_yaml_file + extension if environment is None else data_yaml_file + '_' + environment + extension
+    return yaml.load(open(os.path.dirname(sFile) + file_name), Loader=yaml.FullLoader)[connection_type]
+
+
+def get_log_file_path(file_name):
+    try:
+        sFile = os.path.abspath(sys.modules['__main__'].__file__)
+    except:
+        sFile = sys.executable
+    return os.path.dirname(sFile) + '/' + file_name
 
 
 def get_dynamo_table(access_key, secret_access_key, region, table):
